"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .ragieerror import RagieError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .accesstokencredentials import (
        AccessTokenCredentials,
        AccessTokenCredentialsTypedDict,
    )
    from .agent_hopps_models_models_usage import (
        AgentHoppsModelsModelsUsage,
        AgentHoppsModelsModelsUsageTypedDict,
    )
    from .answer import Answer, AnswerTypedDict
    from .answerstep import AnswerStep, AnswerStepTypedDict
    from .asyncdocumentmetadataupdate import (
        AsyncDocumentMetadataUpdate,
        AsyncDocumentMetadataUpdateTypedDict,
    )
    from .audiomodalitydata import AudioModalityData, AudioModalityDataTypedDict
    from .authenticatorconfluenceconnection import (
        AuthenticatorConfluenceConnection,
        AuthenticatorConfluenceConnectionTypedDict,
    )
    from .authenticatordropboxconnection import (
        AuthenticatorDropboxConnection,
        AuthenticatorDropboxConnectionTypedDict,
    )
    from .authenticatorgmailconnection import (
        AuthenticatorGmailConnection,
        AuthenticatorGmailConnectionTypedDict,
    )
    from .authenticatorgoogledriveconnection import (
        AuthenticatorGoogleDriveConnection,
        AuthenticatorGoogleDriveConnectionTypedDict,
    )
    from .authenticatorhubspotconnection import (
        AuthenticatorHubspotConnection,
        AuthenticatorHubspotConnectionTypedDict,
    )
    from .authenticatorjiraconnection import (
        AuthenticatorJiraConnection,
        AuthenticatorJiraConnectionTypedDict,
    )
    from .authenticatorlist import AuthenticatorList, AuthenticatorListTypedDict
    from .authenticatornotionconnection import (
        AuthenticatorNotionConnection,
        AuthenticatorNotionConnectionTypedDict,
    )
    from .authenticatoronedriveconnection import (
        AuthenticatorOnedriveConnection,
        AuthenticatorOnedriveConnectionTypedDict,
    )
    from .authenticatorsalesforceconnection import (
        AuthenticatorSalesforceConnection,
        AuthenticatorSalesforceConnectionTypedDict,
    )
    from .authenticatorsharepointconnection import (
        AuthenticatorSharepointConnection,
        AuthenticatorSharepointConnectionTypedDict,
    )
    from .authenticatorslackconnection import (
        AuthenticatorSlackConnection,
        AuthenticatorSlackConnectionTypedDict,
    )
    from .backblazecredentials import (
        BackblazeCredentials,
        BackblazeCredentialsTypedDict,
    )
    from .basegetauthenticator import (
        BaseGetAuthenticator,
        BaseGetAuthenticatorTypedDict,
    )
    from .bucketdata import BucketData, BucketDataTypedDict
    from .codeinterpreterevidence import (
        CodeInterpreterEvidence,
        CodeInterpreterEvidenceTypedDict,
    )
    from .codestep import CodeStep, CodeStepTypedDict
    from .confluencedata import ConfluenceData, ConfluenceDataTypedDict
    from .connection import (
        Connection,
        ConnectionMetadata,
        ConnectionMetadataTypedDict,
        ConnectionTypedDict,
        DisabledBySystemReason,
        Source,
        SourceTypedDict,
    )
    from .connectionbase import (
        ConnectionBase,
        ConnectionBaseMetadata,
        ConnectionBaseMetadataTypedDict,
        ConnectionBaseTypedDict,
        PartitionStrategy,
        PartitionStrategy1,
        PartitionStrategyTypedDict,
    )
    from .connectionlimitparams import (
        ConnectionLimitParams,
        ConnectionLimitParamsTypedDict,
    )
    from .connectionlist import ConnectionList, ConnectionListTypedDict
    from .connectionstats import ConnectionStats, ConnectionStatsTypedDict
    from .connectorsource import ConnectorSource
    from .connectorsourcetypeinfo import (
        ConnectorSourceTypeInfo,
        ConnectorSourceTypeInfoTypedDict,
    )
    from .createauthenticatorconnection import (
        CreateAuthenticatorConnection,
        CreateAuthenticatorConnectionConnection,
        CreateAuthenticatorConnectionConnectionTypedDict,
        CreateAuthenticatorConnectionMetadata,
        CreateAuthenticatorConnectionMetadataTypedDict,
        CreateAuthenticatorConnectionTypedDict,
    )
    from .createauthenticatorconnectionop import (
        CreateAuthenticatorConnectionRequest,
        CreateAuthenticatorConnectionRequestTypedDict,
    )
    from .createauthenticatorop import (
        CreateAuthenticatorPayload,
        CreateAuthenticatorPayloadTypedDict,
    )
    from .createdocumentfromurlparams import (
        CreateDocumentFromURLParams,
        CreateDocumentFromURLParamsMetadata,
        CreateDocumentFromURLParamsMetadataTypedDict,
        CreateDocumentFromURLParamsMode,
        CreateDocumentFromURLParamsModeTypedDict,
        CreateDocumentFromURLParamsTypedDict,
        Mode1,
    )
    from .createdocumentparams import (
        CreateDocumentParams,
        CreateDocumentParamsTypedDict,
        File,
        FileTypedDict,
        Metadata,
        MetadataTypedDict,
        Mode,
        ModeStatic,
        ModeTypedDict,
        ModeVideo,
        One,
        One1,
        One2,
        One2TypedDict,
        OneTypedDict,
        Two,
        TwoTypedDict,
    )
    from .createdocumentrawparams import (
        CreateDocumentRawParams,
        CreateDocumentRawParamsMetadata,
        CreateDocumentRawParamsMetadataTypedDict,
        CreateDocumentRawParamsTypedDict,
        Data,
        DataTypedDict,
    )
    from .creategoogleauthenticator import (
        CreateGoogleAuthenticator,
        CreateGoogleAuthenticatorTypedDict,
    )
    from .createinstructionparams import (
        CreateInstructionParams,
        CreateInstructionParamsScope,
        CreateInstructionParamsTypedDict,
    )
    from .createpartitionparams import (
        CreatePartitionParams,
        CreatePartitionParamsTypedDict,
        MetadataSchema,
        MetadataSchemaTypedDict,
    )
    from .delete_connection_connections_connection_id_delete_postop import (
        DeleteConnectionConnectionsConnectionIDDeletePostRequest,
        DeleteConnectionConnectionsConnectionIDDeletePostRequestTypedDict,
    )
    from .delete_partition_partitions_partition_id_deleteop import (
        DeletePartitionPartitionsPartitionIDDeleteRequest,
        DeletePartitionPartitionsPartitionIDDeleteRequestTypedDict,
    )
    from .deleteauthenticatorconnectionop import (
        DeleteAuthenticatorConnectionRequest,
        DeleteAuthenticatorConnectionRequestTypedDict,
    )
    from .deleteconnectionpayload import (
        DeleteConnectionPayload,
        DeleteConnectionPayloadTypedDict,
    )
    from .deletedocumentop import DeleteDocumentRequest, DeleteDocumentRequestTypedDict
    from .deleteinstructionop import (
        DeleteInstructionRequest,
        DeleteInstructionRequestTypedDict,
    )
    from .document import (
        Document,
        DocumentMetadata,
        DocumentMetadataTypedDict,
        DocumentTypedDict,
    )
    from .documentchunk import DocumentChunk, DocumentChunkTypedDict
    from .documentchunkdetail import (
        DocumentChunkDetail,
        DocumentChunkDetailTypedDict,
        ModalityData,
        ModalityDataTypedDict,
    )
    from .documentchunklist import DocumentChunkList, DocumentChunkListTypedDict
    from .documentdelete import DocumentDelete, DocumentDeleteTypedDict
    from .documentfileupdate import DocumentFileUpdate, DocumentFileUpdateTypedDict
    from .documentget import (
        DocumentGet,
        DocumentGetMetadata,
        DocumentGetMetadataTypedDict,
        DocumentGetTypedDict,
    )
    from .documentlist import DocumentList, DocumentListTypedDict
    from .documentmetadataupdate import (
        DocumentMetadataUpdate,
        DocumentMetadataUpdateMetadata,
        DocumentMetadataUpdateMetadataTypedDict,
        DocumentMetadataUpdateTypedDict,
    )
    from .documentrawupdate import DocumentRawUpdate, DocumentRawUpdateTypedDict
    from .documentsummary import DocumentSummary, DocumentSummaryTypedDict
    from .documenturlupdate import DocumentURLUpdate, DocumentURLUpdateTypedDict
    from .documentwithcontent import (
        DocumentWithContent,
        DocumentWithContentMetadata,
        DocumentWithContentMetadataTypedDict,
        DocumentWithContentTypedDict,
    )
    from .entity import Entity, EntityTypedDict
    from .entitylist import EntityList, EntityListTypedDict
    from .errormessage import ErrorMessage, ErrorMessageData
    from .evaluatedanswerstep import EvaluatedAnswerStep, EvaluatedAnswerStepTypedDict
    from .finalanswer import (
        Evidence,
        EvidenceTypedDict,
        FinalAnswer,
        FinalAnswerTypedDict,
        Steps,
        StepsTypedDict,
    )
    from .folderdata import FolderData, FolderDataTypedDict
    from .freshdeskcredentials import (
        FreshdeskCredentials,
        FreshdeskCredentialsTypedDict,
    )
    from .freshdeskdata import FreshdeskData, FreshdeskDataTypedDict
    from .get_connection_connections_connection_id_getop import (
        GetConnectionConnectionsConnectionIDGetRequest,
        GetConnectionConnectionsConnectionIDGetRequestTypedDict,
    )
    from .get_connection_stats_connections_connection_id_stats_getop import (
        GetConnectionStatsConnectionsConnectionIDStatsGetRequest,
        GetConnectionStatsConnectionsConnectionIDStatsGetRequestTypedDict,
    )
    from .get_partition_partitions_partition_id_getop import (
        GetPartitionPartitionsPartitionIDGetRequest,
        GetPartitionPartitionsPartitionIDGetRequestTypedDict,
    )
    from .get_response_responses_response_id_getop import (
        GetResponseResponsesResponseIDGetRequest,
        GetResponseResponsesResponseIDGetRequestTypedDict,
    )
    from .getdocumentchunkcontentop import (
        GetDocumentChunkContentRequest,
        GetDocumentChunkContentRequestTypedDict,
        MediaType,
    )
    from .getdocumentchunkop import (
        GetDocumentChunkRequest,
        GetDocumentChunkRequestTypedDict,
    )
    from .getdocumentchunksop import (
        GetDocumentChunksRequest,
        GetDocumentChunksRequestTypedDict,
    )
    from .getdocumentcontentop import (
        GetDocumentContentRequest,
        GetDocumentContentRequestTypedDict,
        QueryParam1,
        QueryParamMediaType,
        QueryParamMediaTypeTypedDict,
    )
    from .getdocumentop import GetDocumentRequest, GetDocumentRequestTypedDict
    from .getdocumentsourceop import (
        GetDocumentSourceRequest,
        GetDocumentSourceRequestTypedDict,
    )
    from .getdocumentsummaryop import (
        GetDocumentSummaryRequest,
        GetDocumentSummaryRequestTypedDict,
    )
    from .gmaildata import GmailData, GmailDataTypedDict
    from .googlefolderdata import GoogleFolderData, GoogleFolderDataTypedDict
    from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
    from .hubspotdata import HubspotData, HubspotDataTypedDict
    from .inputtokendetails import InputTokenDetails, InputTokenDetailsTypedDict
    from .instruction import Instruction, InstructionTypedDict, Scope
    from .intercomcredentials import IntercomCredentials, IntercomCredentialsTypedDict
    from .intercomdata import IntercomData, IntercomDataTypedDict
    from .link import Link, LinkTypedDict
    from .list_connections_connections_getop import (
        ListConnectionsConnectionsGetRequest,
        ListConnectionsConnectionsGetRequestTypedDict,
        ListConnectionsConnectionsGetResponse,
        ListConnectionsConnectionsGetResponseTypedDict,
    )
    from .list_partitions_partitions_getop import (
        ListPartitionsPartitionsGetRequest,
        ListPartitionsPartitionsGetRequestTypedDict,
        ListPartitionsPartitionsGetResponse,
        ListPartitionsPartitionsGetResponseTypedDict,
    )
    from .listauthenticatorsop import (
        ListAuthenticatorsRequest,
        ListAuthenticatorsRequestTypedDict,
        ListAuthenticatorsResponse,
        ListAuthenticatorsResponseTypedDict,
    )
    from .listconnectorsourcetypeinfo import (
        ListConnectorSourceTypeInfo,
        ListConnectorSourceTypeInfoTypedDict,
    )
    from .listdocumentsop import (
        ListDocumentsRequest,
        ListDocumentsRequestTypedDict,
        ListDocumentsResponse,
        ListDocumentsResponseTypedDict,
    )
    from .listentitiesbydocumentop import (
        ListEntitiesByDocumentRequest,
        ListEntitiesByDocumentRequestTypedDict,
        ListEntitiesByDocumentResponse,
        ListEntitiesByDocumentResponseTypedDict,
    )
    from .listentitiesbyinstructionop import (
        ListEntitiesByInstructionRequest,
        ListEntitiesByInstructionRequestTypedDict,
        ListEntitiesByInstructionResponse,
        ListEntitiesByInstructionResponseTypedDict,
    )
    from .mediamodeparam import MediaModeParam, MediaModeParamTypedDict, Static, Video
    from .modelusage import ModelUsage, ModelUsageTypedDict
    from .no_response_error import NoResponseError
    from .oauthcredentials import OAuthCredentials, OAuthCredentialsTypedDict, Provider
    from .oauthrefreshtokencredentials import (
        OAuthRefreshTokenCredentials,
        OAuthRefreshTokenCredentialsTypedDict,
    )
    from .oauthurlcreate import (
        OAuthURLCreate,
        OAuthURLCreateMetadata,
        OAuthURLCreateMetadataTypedDict,
        OAuthURLCreateMode,
        OAuthURLCreateMode1,
        OAuthURLCreateModeTypedDict,
        OAuthURLCreateTypedDict,
        Theme,
    )
    from .oauthurlresponse import OAuthURLResponse, OAuthURLResponseTypedDict
    from .onedrivedata import OnedriveData, OnedriveDataTypedDict
    from .outputtokendetails import OutputTokenDetails, OutputTokenDetailsTypedDict
    from .pagination import Pagination, PaginationTypedDict
    from .partition import Partition, PartitionTypedDict
    from .partitiondetail import PartitionDetail, PartitionDetailTypedDict
    from .partitionlimitparams import (
        PartitionLimitParams,
        PartitionLimitParamsTypedDict,
    )
    from .partitionlimits import PartitionLimits, PartitionLimitsTypedDict
    from .partitionlist import PartitionList, PartitionListTypedDict
    from .partitionstats import PartitionStats, PartitionStatsTypedDict
    from .patchdocumentmetadataop import (
        PatchDocumentMetadataRequest,
        PatchDocumentMetadataRequestTypedDict,
        PatchDocumentMetadataResponsePatchdocumentmetadata,
        PatchDocumentMetadataResponsePatchdocumentmetadataTypedDict,
    )
    from .patchdocumentmetadataparams import (
        PatchDocumentMetadataParams,
        PatchDocumentMetadataParamsTypedDict,
    )
    from .planstep import PlanStep, PlanStepTypedDict
    from .publicbackblazeconnection import (
        PublicBackblazeConnection,
        PublicBackblazeConnectionTypedDict,
    )
    from .publiccreateconnection import (
        PublicCreateConnection,
        PublicCreateConnectionConnection,
        PublicCreateConnectionConnectionTypedDict,
        PublicCreateConnectionMetadata,
        PublicCreateConnectionMetadataTypedDict,
        PublicCreateConnectionTypedDict,
    )
    from .publicfreshdeskconnection import (
        PublicFreshdeskConnection,
        PublicFreshdeskConnectionTypedDict,
    )
    from .publicgcsconnection import PublicGCSConnection, PublicGCSConnectionTypedDict
    from .publicintercomconnection import (
        PublicIntercomConnection,
        PublicIntercomConnectionTypedDict,
    )
    from .publics3compatibleconnection import (
        PublicS3CompatibleConnection,
        PublicS3CompatibleConnectionTypedDict,
    )
    from .publiczendeskconnection import (
        PublicZendeskConnection,
        PublicZendeskConnectionTypedDict,
    )
    from .ragie_api_schema_response_usage import (
        RagieAPISchemaResponseUsage,
        RagieAPISchemaResponseUsageTypedDict,
    )
    from .ragieevidence import RagieEvidence, RagieEvidenceTypedDict
    from .reasoning import Effort, Reasoning, ReasoningTypedDict
    from .request import Request, RequestTypedDict
    from .response import Response, ResponseTypedDict, Status
    from .responsecontent import ResponseContent, ResponseContentTypedDict
    from .responseok import ResponseOK, ResponseOKTypedDict
    from .responseoutput import ResponseOutput, ResponseOutputTypedDict
    from .responsevalidationerror import ResponseValidationError
    from .retrieval import Retrieval, RetrievalTypedDict
    from .retrieveparams import RetrieveParams, RetrieveParamsTypedDict
    from .s3compatiblecredentials import (
        S3CompatibleCredentials,
        S3CompatibleCredentialsTypedDict,
    )
    from .scoredchunk import ScoredChunk, ScoredChunkTypedDict
    from .sdkerror import SDKError
    from .search import Search, SearchTypedDict
    from .searchresultlink import SearchResultLink, SearchResultLinkTypedDict
    from .searchstep import SearchStep, SearchStepTypedDict
    from .security import Security, SecurityTypedDict
    from .set_connection_enabled_connections_connection_id_enabled_putop import (
        SetConnectionEnabledConnectionsConnectionIDEnabledPutRequest,
        SetConnectionEnabledConnectionsConnectionIDEnabledPutRequestTypedDict,
    )
    from .set_connection_limits_connections_connection_id_limit_putop import (
        SetConnectionLimitsConnectionsConnectionIDLimitPutRequest,
        SetConnectionLimitsConnectionsConnectionIDLimitPutRequestTypedDict,
    )
    from .set_partition_limits_partitions_partition_id_limits_putop import (
        SetPartitionLimitsPartitionsPartitionIDLimitsPutRequest,
        SetPartitionLimitsPartitionsPartitionIDLimitsPutRequestTypedDict,
    )
    from .setconnectionenabledpayload import (
        Reason,
        SetConnectionEnabledPayload,
        SetConnectionEnabledPayloadTypedDict,
    )
    from .sharepointdata import SharepointData, SharepointDataTypedDict
    from .sharepointfiledata import (
        SharepointFileData,
        SharepointFileDataTypedDict,
        Type,
    )
    from .sharepointsitedata import SharepointSiteData, SharepointSiteDataTypedDict
    from .slackdata import SlackData, SlackDataTypedDict
    from .surrenderstep import SurrenderStep, SurrenderStepTypedDict
    from .syncconnectionop import SyncConnectionRequest, SyncConnectionRequestTypedDict
    from .tool import Tool, ToolTypedDict
    from .update_connection_connections_connection_id_putop import (
        UpdateConnectionConnectionsConnectionIDPutRequest,
        UpdateConnectionConnectionsConnectionIDPutRequestTypedDict,
    )
    from .updatedocumentfileop import (
        UpdateDocumentFileRequest,
        UpdateDocumentFileRequestTypedDict,
    )
    from .updatedocumentfileparams import (
        Mode2,
        Mode2TypedDict,
        UpdateDocumentFileParams,
        UpdateDocumentFileParams11,
        UpdateDocumentFileParams12,
        UpdateDocumentFileParams12TypedDict,
        UpdateDocumentFileParamsFile,
        UpdateDocumentFileParamsFileTypedDict,
        UpdateDocumentFileParamsMode,
        UpdateDocumentFileParamsMode1,
        UpdateDocumentFileParamsMode1TypedDict,
        UpdateDocumentFileParamsModeStatic,
        UpdateDocumentFileParamsModeTypedDict,
        UpdateDocumentFileParamsModeVideo,
        UpdateDocumentFileParamsTypedDict,
    )
    from .updatedocumentfromurlop import (
        UpdateDocumentFromURLRequest,
        UpdateDocumentFromURLRequestTypedDict,
    )
    from .updatedocumentfromurlparams import (
        UpdateDocumentFromURLParams,
        UpdateDocumentFromURLParamsMode,
        UpdateDocumentFromURLParamsMode1,
        UpdateDocumentFromURLParamsModeTypedDict,
        UpdateDocumentFromURLParamsTypedDict,
    )
    from .updatedocumentrawop import (
        UpdateDocumentRawRequest,
        UpdateDocumentRawRequestTypedDict,
    )
    from .updatedocumentrawparams import (
        UpdateDocumentRawParams,
        UpdateDocumentRawParamsData,
        UpdateDocumentRawParamsDataTypedDict,
        UpdateDocumentRawParamsTypedDict,
    )
    from .updateinstructionop import (
        UpdateInstructionRequest,
        UpdateInstructionRequestTypedDict,
    )
    from .updateinstructionparams import (
        UpdateInstructionParams,
        UpdateInstructionParamsTypedDict,
    )
    from .validationerror import (
        Loc,
        LocTypedDict,
        ValidationError,
        ValidationErrorTypedDict,
    )
    from .videomodalitydata import VideoModalityData, VideoModalityDataTypedDict
    from .wordtimestamp import WordTimestamp, WordTimestampTypedDict
    from .zendeskcredentials import ZendeskCredentials, ZendeskCredentialsTypedDict
    from .zendeskdata import ZendeskData, ZendeskDataTypedDict

__all__ = [
    "AccessTokenCredentials",
    "AccessTokenCredentialsTypedDict",
    "AgentHoppsModelsModelsUsage",
    "AgentHoppsModelsModelsUsageTypedDict",
    "Answer",
    "AnswerStep",
    "AnswerStepTypedDict",
    "AnswerTypedDict",
    "AsyncDocumentMetadataUpdate",
    "AsyncDocumentMetadataUpdateTypedDict",
    "AudioModalityData",
    "AudioModalityDataTypedDict",
    "AuthenticatorConfluenceConnection",
    "AuthenticatorConfluenceConnectionTypedDict",
    "AuthenticatorDropboxConnection",
    "AuthenticatorDropboxConnectionTypedDict",
    "AuthenticatorGmailConnection",
    "AuthenticatorGmailConnectionTypedDict",
    "AuthenticatorGoogleDriveConnection",
    "AuthenticatorGoogleDriveConnectionTypedDict",
    "AuthenticatorHubspotConnection",
    "AuthenticatorHubspotConnectionTypedDict",
    "AuthenticatorJiraConnection",
    "AuthenticatorJiraConnectionTypedDict",
    "AuthenticatorList",
    "AuthenticatorListTypedDict",
    "AuthenticatorNotionConnection",
    "AuthenticatorNotionConnectionTypedDict",
    "AuthenticatorOnedriveConnection",
    "AuthenticatorOnedriveConnectionTypedDict",
    "AuthenticatorSalesforceConnection",
    "AuthenticatorSalesforceConnectionTypedDict",
    "AuthenticatorSharepointConnection",
    "AuthenticatorSharepointConnectionTypedDict",
    "AuthenticatorSlackConnection",
    "AuthenticatorSlackConnectionTypedDict",
    "BackblazeCredentials",
    "BackblazeCredentialsTypedDict",
    "BaseGetAuthenticator",
    "BaseGetAuthenticatorTypedDict",
    "BucketData",
    "BucketDataTypedDict",
    "CodeInterpreterEvidence",
    "CodeInterpreterEvidenceTypedDict",
    "CodeStep",
    "CodeStepTypedDict",
    "ConfluenceData",
    "ConfluenceDataTypedDict",
    "Connection",
    "ConnectionBase",
    "ConnectionBaseMetadata",
    "ConnectionBaseMetadataTypedDict",
    "ConnectionBaseTypedDict",
    "ConnectionLimitParams",
    "ConnectionLimitParamsTypedDict",
    "ConnectionList",
    "ConnectionListTypedDict",
    "ConnectionMetadata",
    "ConnectionMetadataTypedDict",
    "ConnectionStats",
    "ConnectionStatsTypedDict",
    "ConnectionTypedDict",
    "ConnectorSource",
    "ConnectorSourceTypeInfo",
    "ConnectorSourceTypeInfoTypedDict",
    "CreateAuthenticatorConnection",
    "CreateAuthenticatorConnectionConnection",
    "CreateAuthenticatorConnectionConnectionTypedDict",
    "CreateAuthenticatorConnectionMetadata",
    "CreateAuthenticatorConnectionMetadataTypedDict",
    "CreateAuthenticatorConnectionRequest",
    "CreateAuthenticatorConnectionRequestTypedDict",
    "CreateAuthenticatorConnectionTypedDict",
    "CreateAuthenticatorPayload",
    "CreateAuthenticatorPayloadTypedDict",
    "CreateDocumentFromURLParams",
    "CreateDocumentFromURLParamsMetadata",
    "CreateDocumentFromURLParamsMetadataTypedDict",
    "CreateDocumentFromURLParamsMode",
    "CreateDocumentFromURLParamsModeTypedDict",
    "CreateDocumentFromURLParamsTypedDict",
    "CreateDocumentParams",
    "CreateDocumentParamsTypedDict",
    "CreateDocumentRawParams",
    "CreateDocumentRawParamsMetadata",
    "CreateDocumentRawParamsMetadataTypedDict",
    "CreateDocumentRawParamsTypedDict",
    "CreateGoogleAuthenticator",
    "CreateGoogleAuthenticatorTypedDict",
    "CreateInstructionParams",
    "CreateInstructionParamsScope",
    "CreateInstructionParamsTypedDict",
    "CreatePartitionParams",
    "CreatePartitionParamsTypedDict",
    "Data",
    "DataTypedDict",
    "DeleteAuthenticatorConnectionRequest",
    "DeleteAuthenticatorConnectionRequestTypedDict",
    "DeleteConnectionConnectionsConnectionIDDeletePostRequest",
    "DeleteConnectionConnectionsConnectionIDDeletePostRequestTypedDict",
    "DeleteConnectionPayload",
    "DeleteConnectionPayloadTypedDict",
    "DeleteDocumentRequest",
    "DeleteDocumentRequestTypedDict",
    "DeleteInstructionRequest",
    "DeleteInstructionRequestTypedDict",
    "DeletePartitionPartitionsPartitionIDDeleteRequest",
    "DeletePartitionPartitionsPartitionIDDeleteRequestTypedDict",
    "DisabledBySystemReason",
    "Document",
    "DocumentChunk",
    "DocumentChunkDetail",
    "DocumentChunkDetailTypedDict",
    "DocumentChunkList",
    "DocumentChunkListTypedDict",
    "DocumentChunkTypedDict",
    "DocumentDelete",
    "DocumentDeleteTypedDict",
    "DocumentFileUpdate",
    "DocumentFileUpdateTypedDict",
    "DocumentGet",
    "DocumentGetMetadata",
    "DocumentGetMetadataTypedDict",
    "DocumentGetTypedDict",
    "DocumentList",
    "DocumentListTypedDict",
    "DocumentMetadata",
    "DocumentMetadataTypedDict",
    "DocumentMetadataUpdate",
    "DocumentMetadataUpdateMetadata",
    "DocumentMetadataUpdateMetadataTypedDict",
    "DocumentMetadataUpdateTypedDict",
    "DocumentRawUpdate",
    "DocumentRawUpdateTypedDict",
    "DocumentSummary",
    "DocumentSummaryTypedDict",
    "DocumentTypedDict",
    "DocumentURLUpdate",
    "DocumentURLUpdateTypedDict",
    "DocumentWithContent",
    "DocumentWithContentMetadata",
    "DocumentWithContentMetadataTypedDict",
    "DocumentWithContentTypedDict",
    "Effort",
    "Entity",
    "EntityList",
    "EntityListTypedDict",
    "EntityTypedDict",
    "ErrorMessage",
    "ErrorMessageData",
    "EvaluatedAnswerStep",
    "EvaluatedAnswerStepTypedDict",
    "Evidence",
    "EvidenceTypedDict",
    "File",
    "FileTypedDict",
    "FinalAnswer",
    "FinalAnswerTypedDict",
    "FolderData",
    "FolderDataTypedDict",
    "FreshdeskCredentials",
    "FreshdeskCredentialsTypedDict",
    "FreshdeskData",
    "FreshdeskDataTypedDict",
    "GetConnectionConnectionsConnectionIDGetRequest",
    "GetConnectionConnectionsConnectionIDGetRequestTypedDict",
    "GetConnectionStatsConnectionsConnectionIDStatsGetRequest",
    "GetConnectionStatsConnectionsConnectionIDStatsGetRequestTypedDict",
    "GetDocumentChunkContentRequest",
    "GetDocumentChunkContentRequestTypedDict",
    "GetDocumentChunkRequest",
    "GetDocumentChunkRequestTypedDict",
    "GetDocumentChunksRequest",
    "GetDocumentChunksRequestTypedDict",
    "GetDocumentContentRequest",
    "GetDocumentContentRequestTypedDict",
    "GetDocumentRequest",
    "GetDocumentRequestTypedDict",
    "GetDocumentSourceRequest",
    "GetDocumentSourceRequestTypedDict",
    "GetDocumentSummaryRequest",
    "GetDocumentSummaryRequestTypedDict",
    "GetPartitionPartitionsPartitionIDGetRequest",
    "GetPartitionPartitionsPartitionIDGetRequestTypedDict",
    "GetResponseResponsesResponseIDGetRequest",
    "GetResponseResponsesResponseIDGetRequestTypedDict",
    "GmailData",
    "GmailDataTypedDict",
    "GoogleFolderData",
    "GoogleFolderDataTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "HubspotData",
    "HubspotDataTypedDict",
    "InputTokenDetails",
    "InputTokenDetailsTypedDict",
    "Instruction",
    "InstructionTypedDict",
    "IntercomCredentials",
    "IntercomCredentialsTypedDict",
    "IntercomData",
    "IntercomDataTypedDict",
    "Link",
    "LinkTypedDict",
    "ListAuthenticatorsRequest",
    "ListAuthenticatorsRequestTypedDict",
    "ListAuthenticatorsResponse",
    "ListAuthenticatorsResponseTypedDict",
    "ListConnectionsConnectionsGetRequest",
    "ListConnectionsConnectionsGetRequestTypedDict",
    "ListConnectionsConnectionsGetResponse",
    "ListConnectionsConnectionsGetResponseTypedDict",
    "ListConnectorSourceTypeInfo",
    "ListConnectorSourceTypeInfoTypedDict",
    "ListDocumentsRequest",
    "ListDocumentsRequestTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseTypedDict",
    "ListEntitiesByDocumentRequest",
    "ListEntitiesByDocumentRequestTypedDict",
    "ListEntitiesByDocumentResponse",
    "ListEntitiesByDocumentResponseTypedDict",
    "ListEntitiesByInstructionRequest",
    "ListEntitiesByInstructionRequestTypedDict",
    "ListEntitiesByInstructionResponse",
    "ListEntitiesByInstructionResponseTypedDict",
    "ListPartitionsPartitionsGetRequest",
    "ListPartitionsPartitionsGetRequestTypedDict",
    "ListPartitionsPartitionsGetResponse",
    "ListPartitionsPartitionsGetResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "MediaModeParam",
    "MediaModeParamTypedDict",
    "MediaType",
    "Metadata",
    "MetadataSchema",
    "MetadataSchemaTypedDict",
    "MetadataTypedDict",
    "ModalityData",
    "ModalityDataTypedDict",
    "Mode",
    "Mode1",
    "Mode2",
    "Mode2TypedDict",
    "ModeStatic",
    "ModeTypedDict",
    "ModeVideo",
    "ModelUsage",
    "ModelUsageTypedDict",
    "NoResponseError",
    "OAuthCredentials",
    "OAuthCredentialsTypedDict",
    "OAuthRefreshTokenCredentials",
    "OAuthRefreshTokenCredentialsTypedDict",
    "OAuthURLCreate",
    "OAuthURLCreateMetadata",
    "OAuthURLCreateMetadataTypedDict",
    "OAuthURLCreateMode",
    "OAuthURLCreateMode1",
    "OAuthURLCreateModeTypedDict",
    "OAuthURLCreateTypedDict",
    "OAuthURLResponse",
    "OAuthURLResponseTypedDict",
    "One",
    "One1",
    "One2",
    "One2TypedDict",
    "OneTypedDict",
    "OnedriveData",
    "OnedriveDataTypedDict",
    "OutputTokenDetails",
    "OutputTokenDetailsTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "Partition",
    "PartitionDetail",
    "PartitionDetailTypedDict",
    "PartitionLimitParams",
    "PartitionLimitParamsTypedDict",
    "PartitionLimits",
    "PartitionLimitsTypedDict",
    "PartitionList",
    "PartitionListTypedDict",
    "PartitionStats",
    "PartitionStatsTypedDict",
    "PartitionStrategy",
    "PartitionStrategy1",
    "PartitionStrategyTypedDict",
    "PartitionTypedDict",
    "PatchDocumentMetadataParams",
    "PatchDocumentMetadataParamsTypedDict",
    "PatchDocumentMetadataRequest",
    "PatchDocumentMetadataRequestTypedDict",
    "PatchDocumentMetadataResponsePatchdocumentmetadata",
    "PatchDocumentMetadataResponsePatchdocumentmetadataTypedDict",
    "PlanStep",
    "PlanStepTypedDict",
    "Provider",
    "PublicBackblazeConnection",
    "PublicBackblazeConnectionTypedDict",
    "PublicCreateConnection",
    "PublicCreateConnectionConnection",
    "PublicCreateConnectionConnectionTypedDict",
    "PublicCreateConnectionMetadata",
    "PublicCreateConnectionMetadataTypedDict",
    "PublicCreateConnectionTypedDict",
    "PublicFreshdeskConnection",
    "PublicFreshdeskConnectionTypedDict",
    "PublicGCSConnection",
    "PublicGCSConnectionTypedDict",
    "PublicIntercomConnection",
    "PublicIntercomConnectionTypedDict",
    "PublicS3CompatibleConnection",
    "PublicS3CompatibleConnectionTypedDict",
    "PublicZendeskConnection",
    "PublicZendeskConnectionTypedDict",
    "QueryParam1",
    "QueryParamMediaType",
    "QueryParamMediaTypeTypedDict",
    "RagieAPISchemaResponseUsage",
    "RagieAPISchemaResponseUsageTypedDict",
    "RagieError",
    "RagieEvidence",
    "RagieEvidenceTypedDict",
    "Reason",
    "Reasoning",
    "ReasoningTypedDict",
    "Request",
    "RequestTypedDict",
    "Response",
    "ResponseContent",
    "ResponseContentTypedDict",
    "ResponseOK",
    "ResponseOKTypedDict",
    "ResponseOutput",
    "ResponseOutputTypedDict",
    "ResponseTypedDict",
    "ResponseValidationError",
    "Retrieval",
    "RetrievalTypedDict",
    "RetrieveParams",
    "RetrieveParamsTypedDict",
    "S3CompatibleCredentials",
    "S3CompatibleCredentialsTypedDict",
    "SDKError",
    "Scope",
    "ScoredChunk",
    "ScoredChunkTypedDict",
    "Search",
    "SearchResultLink",
    "SearchResultLinkTypedDict",
    "SearchStep",
    "SearchStepTypedDict",
    "SearchTypedDict",
    "Security",
    "SecurityTypedDict",
    "SetConnectionEnabledConnectionsConnectionIDEnabledPutRequest",
    "SetConnectionEnabledConnectionsConnectionIDEnabledPutRequestTypedDict",
    "SetConnectionEnabledPayload",
    "SetConnectionEnabledPayloadTypedDict",
    "SetConnectionLimitsConnectionsConnectionIDLimitPutRequest",
    "SetConnectionLimitsConnectionsConnectionIDLimitPutRequestTypedDict",
    "SetPartitionLimitsPartitionsPartitionIDLimitsPutRequest",
    "SetPartitionLimitsPartitionsPartitionIDLimitsPutRequestTypedDict",
    "SharepointData",
    "SharepointDataTypedDict",
    "SharepointFileData",
    "SharepointFileDataTypedDict",
    "SharepointSiteData",
    "SharepointSiteDataTypedDict",
    "SlackData",
    "SlackDataTypedDict",
    "Source",
    "SourceTypedDict",
    "Static",
    "Status",
    "Steps",
    "StepsTypedDict",
    "SurrenderStep",
    "SurrenderStepTypedDict",
    "SyncConnectionRequest",
    "SyncConnectionRequestTypedDict",
    "Theme",
    "Tool",
    "ToolTypedDict",
    "Two",
    "TwoTypedDict",
    "Type",
    "UpdateConnectionConnectionsConnectionIDPutRequest",
    "UpdateConnectionConnectionsConnectionIDPutRequestTypedDict",
    "UpdateDocumentFileParams",
    "UpdateDocumentFileParams11",
    "UpdateDocumentFileParams12",
    "UpdateDocumentFileParams12TypedDict",
    "UpdateDocumentFileParamsFile",
    "UpdateDocumentFileParamsFileTypedDict",
    "UpdateDocumentFileParamsMode",
    "UpdateDocumentFileParamsMode1",
    "UpdateDocumentFileParamsMode1TypedDict",
    "UpdateDocumentFileParamsModeStatic",
    "UpdateDocumentFileParamsModeTypedDict",
    "UpdateDocumentFileParamsModeVideo",
    "UpdateDocumentFileParamsTypedDict",
    "UpdateDocumentFileRequest",
    "UpdateDocumentFileRequestTypedDict",
    "UpdateDocumentFromURLParams",
    "UpdateDocumentFromURLParamsMode",
    "UpdateDocumentFromURLParamsMode1",
    "UpdateDocumentFromURLParamsModeTypedDict",
    "UpdateDocumentFromURLParamsTypedDict",
    "UpdateDocumentFromURLRequest",
    "UpdateDocumentFromURLRequestTypedDict",
    "UpdateDocumentRawParams",
    "UpdateDocumentRawParamsData",
    "UpdateDocumentRawParamsDataTypedDict",
    "UpdateDocumentRawParamsTypedDict",
    "UpdateDocumentRawRequest",
    "UpdateDocumentRawRequestTypedDict",
    "UpdateInstructionParams",
    "UpdateInstructionParamsTypedDict",
    "UpdateInstructionRequest",
    "UpdateInstructionRequestTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "Video",
    "VideoModalityData",
    "VideoModalityDataTypedDict",
    "WordTimestamp",
    "WordTimestampTypedDict",
    "ZendeskCredentials",
    "ZendeskCredentialsTypedDict",
    "ZendeskData",
    "ZendeskDataTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AccessTokenCredentials": ".accesstokencredentials",
    "AccessTokenCredentialsTypedDict": ".accesstokencredentials",
    "AgentHoppsModelsModelsUsage": ".agent_hopps_models_models_usage",
    "AgentHoppsModelsModelsUsageTypedDict": ".agent_hopps_models_models_usage",
    "Answer": ".answer",
    "AnswerTypedDict": ".answer",
    "AnswerStep": ".answerstep",
    "AnswerStepTypedDict": ".answerstep",
    "AsyncDocumentMetadataUpdate": ".asyncdocumentmetadataupdate",
    "AsyncDocumentMetadataUpdateTypedDict": ".asyncdocumentmetadataupdate",
    "AudioModalityData": ".audiomodalitydata",
    "AudioModalityDataTypedDict": ".audiomodalitydata",
    "AuthenticatorConfluenceConnection": ".authenticatorconfluenceconnection",
    "AuthenticatorConfluenceConnectionTypedDict": ".authenticatorconfluenceconnection",
    "AuthenticatorDropboxConnection": ".authenticatordropboxconnection",
    "AuthenticatorDropboxConnectionTypedDict": ".authenticatordropboxconnection",
    "AuthenticatorGmailConnection": ".authenticatorgmailconnection",
    "AuthenticatorGmailConnectionTypedDict": ".authenticatorgmailconnection",
    "AuthenticatorGoogleDriveConnection": ".authenticatorgoogledriveconnection",
    "AuthenticatorGoogleDriveConnectionTypedDict": ".authenticatorgoogledriveconnection",
    "AuthenticatorHubspotConnection": ".authenticatorhubspotconnection",
    "AuthenticatorHubspotConnectionTypedDict": ".authenticatorhubspotconnection",
    "AuthenticatorJiraConnection": ".authenticatorjiraconnection",
    "AuthenticatorJiraConnectionTypedDict": ".authenticatorjiraconnection",
    "AuthenticatorList": ".authenticatorlist",
    "AuthenticatorListTypedDict": ".authenticatorlist",
    "AuthenticatorNotionConnection": ".authenticatornotionconnection",
    "AuthenticatorNotionConnectionTypedDict": ".authenticatornotionconnection",
    "AuthenticatorOnedriveConnection": ".authenticatoronedriveconnection",
    "AuthenticatorOnedriveConnectionTypedDict": ".authenticatoronedriveconnection",
    "AuthenticatorSalesforceConnection": ".authenticatorsalesforceconnection",
    "AuthenticatorSalesforceConnectionTypedDict": ".authenticatorsalesforceconnection",
    "AuthenticatorSharepointConnection": ".authenticatorsharepointconnection",
    "AuthenticatorSharepointConnectionTypedDict": ".authenticatorsharepointconnection",
    "AuthenticatorSlackConnection": ".authenticatorslackconnection",
    "AuthenticatorSlackConnectionTypedDict": ".authenticatorslackconnection",
    "BackblazeCredentials": ".backblazecredentials",
    "BackblazeCredentialsTypedDict": ".backblazecredentials",
    "BaseGetAuthenticator": ".basegetauthenticator",
    "BaseGetAuthenticatorTypedDict": ".basegetauthenticator",
    "BucketData": ".bucketdata",
    "BucketDataTypedDict": ".bucketdata",
    "CodeInterpreterEvidence": ".codeinterpreterevidence",
    "CodeInterpreterEvidenceTypedDict": ".codeinterpreterevidence",
    "CodeStep": ".codestep",
    "CodeStepTypedDict": ".codestep",
    "ConfluenceData": ".confluencedata",
    "ConfluenceDataTypedDict": ".confluencedata",
    "Connection": ".connection",
    "ConnectionMetadata": ".connection",
    "ConnectionMetadataTypedDict": ".connection",
    "ConnectionTypedDict": ".connection",
    "DisabledBySystemReason": ".connection",
    "Source": ".connection",
    "SourceTypedDict": ".connection",
    "ConnectionBase": ".connectionbase",
    "ConnectionBaseMetadata": ".connectionbase",
    "ConnectionBaseMetadataTypedDict": ".connectionbase",
    "ConnectionBaseTypedDict": ".connectionbase",
    "PartitionStrategy": ".connectionbase",
    "PartitionStrategy1": ".connectionbase",
    "PartitionStrategyTypedDict": ".connectionbase",
    "ConnectionLimitParams": ".connectionlimitparams",
    "ConnectionLimitParamsTypedDict": ".connectionlimitparams",
    "ConnectionList": ".connectionlist",
    "ConnectionListTypedDict": ".connectionlist",
    "ConnectionStats": ".connectionstats",
    "ConnectionStatsTypedDict": ".connectionstats",
    "ConnectorSource": ".connectorsource",
    "ConnectorSourceTypeInfo": ".connectorsourcetypeinfo",
    "ConnectorSourceTypeInfoTypedDict": ".connectorsourcetypeinfo",
    "CreateAuthenticatorConnection": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionConnection": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionConnectionTypedDict": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionMetadata": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionMetadataTypedDict": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionTypedDict": ".createauthenticatorconnection",
    "CreateAuthenticatorConnectionRequest": ".createauthenticatorconnectionop",
    "CreateAuthenticatorConnectionRequestTypedDict": ".createauthenticatorconnectionop",
    "CreateAuthenticatorPayload": ".createauthenticatorop",
    "CreateAuthenticatorPayloadTypedDict": ".createauthenticatorop",
    "CreateDocumentFromURLParams": ".createdocumentfromurlparams",
    "CreateDocumentFromURLParamsMetadata": ".createdocumentfromurlparams",
    "CreateDocumentFromURLParamsMetadataTypedDict": ".createdocumentfromurlparams",
    "CreateDocumentFromURLParamsMode": ".createdocumentfromurlparams",
    "CreateDocumentFromURLParamsModeTypedDict": ".createdocumentfromurlparams",
    "CreateDocumentFromURLParamsTypedDict": ".createdocumentfromurlparams",
    "Mode1": ".createdocumentfromurlparams",
    "CreateDocumentParams": ".createdocumentparams",
    "CreateDocumentParamsTypedDict": ".createdocumentparams",
    "File": ".createdocumentparams",
    "FileTypedDict": ".createdocumentparams",
    "Metadata": ".createdocumentparams",
    "MetadataTypedDict": ".createdocumentparams",
    "Mode": ".createdocumentparams",
    "ModeStatic": ".createdocumentparams",
    "ModeTypedDict": ".createdocumentparams",
    "ModeVideo": ".createdocumentparams",
    "One": ".createdocumentparams",
    "One1": ".createdocumentparams",
    "One2": ".createdocumentparams",
    "One2TypedDict": ".createdocumentparams",
    "OneTypedDict": ".createdocumentparams",
    "Two": ".createdocumentparams",
    "TwoTypedDict": ".createdocumentparams",
    "CreateDocumentRawParams": ".createdocumentrawparams",
    "CreateDocumentRawParamsMetadata": ".createdocumentrawparams",
    "CreateDocumentRawParamsMetadataTypedDict": ".createdocumentrawparams",
    "CreateDocumentRawParamsTypedDict": ".createdocumentrawparams",
    "Data": ".createdocumentrawparams",
    "DataTypedDict": ".createdocumentrawparams",
    "CreateGoogleAuthenticator": ".creategoogleauthenticator",
    "CreateGoogleAuthenticatorTypedDict": ".creategoogleauthenticator",
    "CreateInstructionParams": ".createinstructionparams",
    "CreateInstructionParamsScope": ".createinstructionparams",
    "CreateInstructionParamsTypedDict": ".createinstructionparams",
    "CreatePartitionParams": ".createpartitionparams",
    "CreatePartitionParamsTypedDict": ".createpartitionparams",
    "MetadataSchema": ".createpartitionparams",
    "MetadataSchemaTypedDict": ".createpartitionparams",
    "DeleteConnectionConnectionsConnectionIDDeletePostRequest": ".delete_connection_connections_connection_id_delete_postop",
    "DeleteConnectionConnectionsConnectionIDDeletePostRequestTypedDict": ".delete_connection_connections_connection_id_delete_postop",
    "DeletePartitionPartitionsPartitionIDDeleteRequest": ".delete_partition_partitions_partition_id_deleteop",
    "DeletePartitionPartitionsPartitionIDDeleteRequestTypedDict": ".delete_partition_partitions_partition_id_deleteop",
    "DeleteAuthenticatorConnectionRequest": ".deleteauthenticatorconnectionop",
    "DeleteAuthenticatorConnectionRequestTypedDict": ".deleteauthenticatorconnectionop",
    "DeleteConnectionPayload": ".deleteconnectionpayload",
    "DeleteConnectionPayloadTypedDict": ".deleteconnectionpayload",
    "DeleteDocumentRequest": ".deletedocumentop",
    "DeleteDocumentRequestTypedDict": ".deletedocumentop",
    "DeleteInstructionRequest": ".deleteinstructionop",
    "DeleteInstructionRequestTypedDict": ".deleteinstructionop",
    "Document": ".document",
    "DocumentMetadata": ".document",
    "DocumentMetadataTypedDict": ".document",
    "DocumentTypedDict": ".document",
    "DocumentChunk": ".documentchunk",
    "DocumentChunkTypedDict": ".documentchunk",
    "DocumentChunkDetail": ".documentchunkdetail",
    "DocumentChunkDetailTypedDict": ".documentchunkdetail",
    "ModalityData": ".documentchunkdetail",
    "ModalityDataTypedDict": ".documentchunkdetail",
    "DocumentChunkList": ".documentchunklist",
    "DocumentChunkListTypedDict": ".documentchunklist",
    "DocumentDelete": ".documentdelete",
    "DocumentDeleteTypedDict": ".documentdelete",
    "DocumentFileUpdate": ".documentfileupdate",
    "DocumentFileUpdateTypedDict": ".documentfileupdate",
    "DocumentGet": ".documentget",
    "DocumentGetMetadata": ".documentget",
    "DocumentGetMetadataTypedDict": ".documentget",
    "DocumentGetTypedDict": ".documentget",
    "DocumentList": ".documentlist",
    "DocumentListTypedDict": ".documentlist",
    "DocumentMetadataUpdate": ".documentmetadataupdate",
    "DocumentMetadataUpdateMetadata": ".documentmetadataupdate",
    "DocumentMetadataUpdateMetadataTypedDict": ".documentmetadataupdate",
    "DocumentMetadataUpdateTypedDict": ".documentmetadataupdate",
    "DocumentRawUpdate": ".documentrawupdate",
    "DocumentRawUpdateTypedDict": ".documentrawupdate",
    "DocumentSummary": ".documentsummary",
    "DocumentSummaryTypedDict": ".documentsummary",
    "DocumentURLUpdate": ".documenturlupdate",
    "DocumentURLUpdateTypedDict": ".documenturlupdate",
    "DocumentWithContent": ".documentwithcontent",
    "DocumentWithContentMetadata": ".documentwithcontent",
    "DocumentWithContentMetadataTypedDict": ".documentwithcontent",
    "DocumentWithContentTypedDict": ".documentwithcontent",
    "Entity": ".entity",
    "EntityTypedDict": ".entity",
    "EntityList": ".entitylist",
    "EntityListTypedDict": ".entitylist",
    "ErrorMessage": ".errormessage",
    "ErrorMessageData": ".errormessage",
    "EvaluatedAnswerStep": ".evaluatedanswerstep",
    "EvaluatedAnswerStepTypedDict": ".evaluatedanswerstep",
    "Evidence": ".finalanswer",
    "EvidenceTypedDict": ".finalanswer",
    "FinalAnswer": ".finalanswer",
    "FinalAnswerTypedDict": ".finalanswer",
    "Steps": ".finalanswer",
    "StepsTypedDict": ".finalanswer",
    "FolderData": ".folderdata",
    "FolderDataTypedDict": ".folderdata",
    "FreshdeskCredentials": ".freshdeskcredentials",
    "FreshdeskCredentialsTypedDict": ".freshdeskcredentials",
    "FreshdeskData": ".freshdeskdata",
    "FreshdeskDataTypedDict": ".freshdeskdata",
    "GetConnectionConnectionsConnectionIDGetRequest": ".get_connection_connections_connection_id_getop",
    "GetConnectionConnectionsConnectionIDGetRequestTypedDict": ".get_connection_connections_connection_id_getop",
    "GetConnectionStatsConnectionsConnectionIDStatsGetRequest": ".get_connection_stats_connections_connection_id_stats_getop",
    "GetConnectionStatsConnectionsConnectionIDStatsGetRequestTypedDict": ".get_connection_stats_connections_connection_id_stats_getop",
    "GetPartitionPartitionsPartitionIDGetRequest": ".get_partition_partitions_partition_id_getop",
    "GetPartitionPartitionsPartitionIDGetRequestTypedDict": ".get_partition_partitions_partition_id_getop",
    "GetResponseResponsesResponseIDGetRequest": ".get_response_responses_response_id_getop",
    "GetResponseResponsesResponseIDGetRequestTypedDict": ".get_response_responses_response_id_getop",
    "GetDocumentChunkContentRequest": ".getdocumentchunkcontentop",
    "GetDocumentChunkContentRequestTypedDict": ".getdocumentchunkcontentop",
    "MediaType": ".getdocumentchunkcontentop",
    "GetDocumentChunkRequest": ".getdocumentchunkop",
    "GetDocumentChunkRequestTypedDict": ".getdocumentchunkop",
    "GetDocumentChunksRequest": ".getdocumentchunksop",
    "GetDocumentChunksRequestTypedDict": ".getdocumentchunksop",
    "GetDocumentContentRequest": ".getdocumentcontentop",
    "GetDocumentContentRequestTypedDict": ".getdocumentcontentop",
    "QueryParam1": ".getdocumentcontentop",
    "QueryParamMediaType": ".getdocumentcontentop",
    "QueryParamMediaTypeTypedDict": ".getdocumentcontentop",
    "GetDocumentRequest": ".getdocumentop",
    "GetDocumentRequestTypedDict": ".getdocumentop",
    "GetDocumentSourceRequest": ".getdocumentsourceop",
    "GetDocumentSourceRequestTypedDict": ".getdocumentsourceop",
    "GetDocumentSummaryRequest": ".getdocumentsummaryop",
    "GetDocumentSummaryRequestTypedDict": ".getdocumentsummaryop",
    "GmailData": ".gmaildata",
    "GmailDataTypedDict": ".gmaildata",
    "GoogleFolderData": ".googlefolderdata",
    "GoogleFolderDataTypedDict": ".googlefolderdata",
    "HTTPValidationError": ".httpvalidationerror",
    "HTTPValidationErrorData": ".httpvalidationerror",
    "HubspotData": ".hubspotdata",
    "HubspotDataTypedDict": ".hubspotdata",
    "InputTokenDetails": ".inputtokendetails",
    "InputTokenDetailsTypedDict": ".inputtokendetails",
    "Instruction": ".instruction",
    "InstructionTypedDict": ".instruction",
    "Scope": ".instruction",
    "IntercomCredentials": ".intercomcredentials",
    "IntercomCredentialsTypedDict": ".intercomcredentials",
    "IntercomData": ".intercomdata",
    "IntercomDataTypedDict": ".intercomdata",
    "Link": ".link",
    "LinkTypedDict": ".link",
    "ListConnectionsConnectionsGetRequest": ".list_connections_connections_getop",
    "ListConnectionsConnectionsGetRequestTypedDict": ".list_connections_connections_getop",
    "ListConnectionsConnectionsGetResponse": ".list_connections_connections_getop",
    "ListConnectionsConnectionsGetResponseTypedDict": ".list_connections_connections_getop",
    "ListPartitionsPartitionsGetRequest": ".list_partitions_partitions_getop",
    "ListPartitionsPartitionsGetRequestTypedDict": ".list_partitions_partitions_getop",
    "ListPartitionsPartitionsGetResponse": ".list_partitions_partitions_getop",
    "ListPartitionsPartitionsGetResponseTypedDict": ".list_partitions_partitions_getop",
    "ListAuthenticatorsRequest": ".listauthenticatorsop",
    "ListAuthenticatorsRequestTypedDict": ".listauthenticatorsop",
    "ListAuthenticatorsResponse": ".listauthenticatorsop",
    "ListAuthenticatorsResponseTypedDict": ".listauthenticatorsop",
    "ListConnectorSourceTypeInfo": ".listconnectorsourcetypeinfo",
    "ListConnectorSourceTypeInfoTypedDict": ".listconnectorsourcetypeinfo",
    "ListDocumentsRequest": ".listdocumentsop",
    "ListDocumentsRequestTypedDict": ".listdocumentsop",
    "ListDocumentsResponse": ".listdocumentsop",
    "ListDocumentsResponseTypedDict": ".listdocumentsop",
    "ListEntitiesByDocumentRequest": ".listentitiesbydocumentop",
    "ListEntitiesByDocumentRequestTypedDict": ".listentitiesbydocumentop",
    "ListEntitiesByDocumentResponse": ".listentitiesbydocumentop",
    "ListEntitiesByDocumentResponseTypedDict": ".listentitiesbydocumentop",
    "ListEntitiesByInstructionRequest": ".listentitiesbyinstructionop",
    "ListEntitiesByInstructionRequestTypedDict": ".listentitiesbyinstructionop",
    "ListEntitiesByInstructionResponse": ".listentitiesbyinstructionop",
    "ListEntitiesByInstructionResponseTypedDict": ".listentitiesbyinstructionop",
    "MediaModeParam": ".mediamodeparam",
    "MediaModeParamTypedDict": ".mediamodeparam",
    "Static": ".mediamodeparam",
    "Video": ".mediamodeparam",
    "ModelUsage": ".modelusage",
    "ModelUsageTypedDict": ".modelusage",
    "NoResponseError": ".no_response_error",
    "OAuthCredentials": ".oauthcredentials",
    "OAuthCredentialsTypedDict": ".oauthcredentials",
    "Provider": ".oauthcredentials",
    "OAuthRefreshTokenCredentials": ".oauthrefreshtokencredentials",
    "OAuthRefreshTokenCredentialsTypedDict": ".oauthrefreshtokencredentials",
    "OAuthURLCreate": ".oauthurlcreate",
    "OAuthURLCreateMetadata": ".oauthurlcreate",
    "OAuthURLCreateMetadataTypedDict": ".oauthurlcreate",
    "OAuthURLCreateMode": ".oauthurlcreate",
    "OAuthURLCreateMode1": ".oauthurlcreate",
    "OAuthURLCreateModeTypedDict": ".oauthurlcreate",
    "OAuthURLCreateTypedDict": ".oauthurlcreate",
    "Theme": ".oauthurlcreate",
    "OAuthURLResponse": ".oauthurlresponse",
    "OAuthURLResponseTypedDict": ".oauthurlresponse",
    "OnedriveData": ".onedrivedata",
    "OnedriveDataTypedDict": ".onedrivedata",
    "OutputTokenDetails": ".outputtokendetails",
    "OutputTokenDetailsTypedDict": ".outputtokendetails",
    "Pagination": ".pagination",
    "PaginationTypedDict": ".pagination",
    "Partition": ".partition",
    "PartitionTypedDict": ".partition",
    "PartitionDetail": ".partitiondetail",
    "PartitionDetailTypedDict": ".partitiondetail",
    "PartitionLimitParams": ".partitionlimitparams",
    "PartitionLimitParamsTypedDict": ".partitionlimitparams",
    "PartitionLimits": ".partitionlimits",
    "PartitionLimitsTypedDict": ".partitionlimits",
    "PartitionList": ".partitionlist",
    "PartitionListTypedDict": ".partitionlist",
    "PartitionStats": ".partitionstats",
    "PartitionStatsTypedDict": ".partitionstats",
    "PatchDocumentMetadataRequest": ".patchdocumentmetadataop",
    "PatchDocumentMetadataRequestTypedDict": ".patchdocumentmetadataop",
    "PatchDocumentMetadataResponsePatchdocumentmetadata": ".patchdocumentmetadataop",
    "PatchDocumentMetadataResponsePatchdocumentmetadataTypedDict": ".patchdocumentmetadataop",
    "PatchDocumentMetadataParams": ".patchdocumentmetadataparams",
    "PatchDocumentMetadataParamsTypedDict": ".patchdocumentmetadataparams",
    "PlanStep": ".planstep",
    "PlanStepTypedDict": ".planstep",
    "PublicBackblazeConnection": ".publicbackblazeconnection",
    "PublicBackblazeConnectionTypedDict": ".publicbackblazeconnection",
    "PublicCreateConnection": ".publiccreateconnection",
    "PublicCreateConnectionConnection": ".publiccreateconnection",
    "PublicCreateConnectionConnectionTypedDict": ".publiccreateconnection",
    "PublicCreateConnectionMetadata": ".publiccreateconnection",
    "PublicCreateConnectionMetadataTypedDict": ".publiccreateconnection",
    "PublicCreateConnectionTypedDict": ".publiccreateconnection",
    "PublicFreshdeskConnection": ".publicfreshdeskconnection",
    "PublicFreshdeskConnectionTypedDict": ".publicfreshdeskconnection",
    "PublicGCSConnection": ".publicgcsconnection",
    "PublicGCSConnectionTypedDict": ".publicgcsconnection",
    "PublicIntercomConnection": ".publicintercomconnection",
    "PublicIntercomConnectionTypedDict": ".publicintercomconnection",
    "PublicS3CompatibleConnection": ".publics3compatibleconnection",
    "PublicS3CompatibleConnectionTypedDict": ".publics3compatibleconnection",
    "PublicZendeskConnection": ".publiczendeskconnection",
    "PublicZendeskConnectionTypedDict": ".publiczendeskconnection",
    "RagieAPISchemaResponseUsage": ".ragie_api_schema_response_usage",
    "RagieAPISchemaResponseUsageTypedDict": ".ragie_api_schema_response_usage",
    "RagieEvidence": ".ragieevidence",
    "RagieEvidenceTypedDict": ".ragieevidence",
    "Effort": ".reasoning",
    "Reasoning": ".reasoning",
    "ReasoningTypedDict": ".reasoning",
    "Request": ".request",
    "RequestTypedDict": ".request",
    "Response": ".response",
    "ResponseTypedDict": ".response",
    "Status": ".response",
    "ResponseContent": ".responsecontent",
    "ResponseContentTypedDict": ".responsecontent",
    "ResponseOK": ".responseok",
    "ResponseOKTypedDict": ".responseok",
    "ResponseOutput": ".responseoutput",
    "ResponseOutputTypedDict": ".responseoutput",
    "ResponseValidationError": ".responsevalidationerror",
    "Retrieval": ".retrieval",
    "RetrievalTypedDict": ".retrieval",
    "RetrieveParams": ".retrieveparams",
    "RetrieveParamsTypedDict": ".retrieveparams",
    "S3CompatibleCredentials": ".s3compatiblecredentials",
    "S3CompatibleCredentialsTypedDict": ".s3compatiblecredentials",
    "ScoredChunk": ".scoredchunk",
    "ScoredChunkTypedDict": ".scoredchunk",
    "SDKError": ".sdkerror",
    "Search": ".search",
    "SearchTypedDict": ".search",
    "SearchResultLink": ".searchresultlink",
    "SearchResultLinkTypedDict": ".searchresultlink",
    "SearchStep": ".searchstep",
    "SearchStepTypedDict": ".searchstep",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SetConnectionEnabledConnectionsConnectionIDEnabledPutRequest": ".set_connection_enabled_connections_connection_id_enabled_putop",
    "SetConnectionEnabledConnectionsConnectionIDEnabledPutRequestTypedDict": ".set_connection_enabled_connections_connection_id_enabled_putop",
    "SetConnectionLimitsConnectionsConnectionIDLimitPutRequest": ".set_connection_limits_connections_connection_id_limit_putop",
    "SetConnectionLimitsConnectionsConnectionIDLimitPutRequestTypedDict": ".set_connection_limits_connections_connection_id_limit_putop",
    "SetPartitionLimitsPartitionsPartitionIDLimitsPutRequest": ".set_partition_limits_partitions_partition_id_limits_putop",
    "SetPartitionLimitsPartitionsPartitionIDLimitsPutRequestTypedDict": ".set_partition_limits_partitions_partition_id_limits_putop",
    "Reason": ".setconnectionenabledpayload",
    "SetConnectionEnabledPayload": ".setconnectionenabledpayload",
    "SetConnectionEnabledPayloadTypedDict": ".setconnectionenabledpayload",
    "SharepointData": ".sharepointdata",
    "SharepointDataTypedDict": ".sharepointdata",
    "SharepointFileData": ".sharepointfiledata",
    "SharepointFileDataTypedDict": ".sharepointfiledata",
    "Type": ".sharepointfiledata",
    "SharepointSiteData": ".sharepointsitedata",
    "SharepointSiteDataTypedDict": ".sharepointsitedata",
    "SlackData": ".slackdata",
    "SlackDataTypedDict": ".slackdata",
    "SurrenderStep": ".surrenderstep",
    "SurrenderStepTypedDict": ".surrenderstep",
    "SyncConnectionRequest": ".syncconnectionop",
    "SyncConnectionRequestTypedDict": ".syncconnectionop",
    "Tool": ".tool",
    "ToolTypedDict": ".tool",
    "UpdateConnectionConnectionsConnectionIDPutRequest": ".update_connection_connections_connection_id_putop",
    "UpdateConnectionConnectionsConnectionIDPutRequestTypedDict": ".update_connection_connections_connection_id_putop",
    "UpdateDocumentFileRequest": ".updatedocumentfileop",
    "UpdateDocumentFileRequestTypedDict": ".updatedocumentfileop",
    "Mode2": ".updatedocumentfileparams",
    "Mode2TypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFileParams": ".updatedocumentfileparams",
    "UpdateDocumentFileParams11": ".updatedocumentfileparams",
    "UpdateDocumentFileParams12": ".updatedocumentfileparams",
    "UpdateDocumentFileParams12TypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsFile": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsFileTypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsMode": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsMode1": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsMode1TypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsModeStatic": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsModeTypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsModeVideo": ".updatedocumentfileparams",
    "UpdateDocumentFileParamsTypedDict": ".updatedocumentfileparams",
    "UpdateDocumentFromURLRequest": ".updatedocumentfromurlop",
    "UpdateDocumentFromURLRequestTypedDict": ".updatedocumentfromurlop",
    "UpdateDocumentFromURLParams": ".updatedocumentfromurlparams",
    "UpdateDocumentFromURLParamsMode": ".updatedocumentfromurlparams",
    "UpdateDocumentFromURLParamsMode1": ".updatedocumentfromurlparams",
    "UpdateDocumentFromURLParamsModeTypedDict": ".updatedocumentfromurlparams",
    "UpdateDocumentFromURLParamsTypedDict": ".updatedocumentfromurlparams",
    "UpdateDocumentRawRequest": ".updatedocumentrawop",
    "UpdateDocumentRawRequestTypedDict": ".updatedocumentrawop",
    "UpdateDocumentRawParams": ".updatedocumentrawparams",
    "UpdateDocumentRawParamsData": ".updatedocumentrawparams",
    "UpdateDocumentRawParamsDataTypedDict": ".updatedocumentrawparams",
    "UpdateDocumentRawParamsTypedDict": ".updatedocumentrawparams",
    "UpdateInstructionRequest": ".updateinstructionop",
    "UpdateInstructionRequestTypedDict": ".updateinstructionop",
    "UpdateInstructionParams": ".updateinstructionparams",
    "UpdateInstructionParamsTypedDict": ".updateinstructionparams",
    "Loc": ".validationerror",
    "LocTypedDict": ".validationerror",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "VideoModalityData": ".videomodalitydata",
    "VideoModalityDataTypedDict": ".videomodalitydata",
    "WordTimestamp": ".wordtimestamp",
    "WordTimestampTypedDict": ".wordtimestamp",
    "ZendeskCredentials": ".zendeskcredentials",
    "ZendeskCredentialsTypedDict": ".zendeskcredentials",
    "ZendeskData": ".zendeskdata",
    "ZendeskDataTypedDict": ".zendeskdata",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
