"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class IntercomCredentialsTypedDict(TypedDict):
    access_token: str
    app_name: str
    user_email: str
    r"""The email of the Intercom account this is for"""


class IntercomCredentials(BaseModel):
    access_token: str

    app_name: str

    user_email: str
    r"""The email of the Intercom account this is for"""
