"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class DeleteConnectionPayloadTypedDict(TypedDict):
    keep_files: bool


class DeleteConnectionPayload(BaseModel):
    keep_files: bool
