"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseOKTypedDict(TypedDict):
    message: NotRequired[str]


class ResponseOK(BaseModel):
    message: Optional[str] = "ok"
