"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .partitionlimitparams import PartitionLimitParams, PartitionLimitParamsTypedDict
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SetPartitionLimitsPartitionsPartitionIDLimitsPutRequestTypedDict(TypedDict):
    partition_id: str
    partition_limit_params: PartitionLimitParamsTypedDict


class SetPartitionLimitsPartitionsPartitionIDLimitsPutRequest(BaseModel):
    partition_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    partition_limit_params: Annotated[
        PartitionLimitParams,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
