"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SearchTypedDict(TypedDict):
    search_requests: List[str]


class Search(BaseModel):
    search_requests: List[str]
