"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Any, Dict, List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ResponseContentTypedDict(TypedDict):
    text: str
    type: Literal["text"]
    annotations: NotRequired[List[Dict[str, Any]]]


class ResponseContent(BaseModel):
    text: str

    TYPE: Annotated[
        Annotated[Optional[Literal["text"]], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"

    annotations: Optional[List[Dict[str, Any]]] = None
