"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class ModelUsageTypedDict(TypedDict):
    model_name: str
    input_tokens: int
    output_tokens: int


class ModelUsage(BaseModel):
    model_name: str

    input_tokens: int

    output_tokens: int
