"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class BaseGetAuthenticatorTypedDict(TypedDict):
    provider: str
    name: str
    r"""The unique name of your authenticator, used to identify it and distinguish it from others. This name must be unique. Attempting to reuse the same name will result in an error."""
    id: str


class BaseGetAuthenticator(BaseModel):
    provider: str

    name: str
    r"""The unique name of your authenticator, used to identify it and distinguish it from others. This name must be unique. Attempting to reuse the same name will result in an error."""

    id: str
