"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .modelusage import ModelUsage, ModelUsageTypedDict
from ragie.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class AgentHoppsModelsModelsUsageTypedDict(TypedDict):
    models: NotRequired[List[ModelUsageTypedDict]]


class AgentHoppsModelsModelsUsage(BaseModel):
    models: Optional[List[ModelUsage]] = None
