"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class HubspotDataTypedDict(TypedDict):
    companies: bool
    contacts: bool
    contact_notes: bool
    deals: bool
    deal_notes: bool
    emails: bool
    tasks: bool


class HubspotData(BaseModel):
    companies: bool

    contacts: bool

    contact_notes: bool

    deals: bool

    deal_notes: bool

    emails: bool

    tasks: bool
