"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class AnswerTypedDict(TypedDict):
    text: str
    r"""An answer to a question."""
    evidence: NotRequired[List[str]]
    r"""The evidence used to derive the answer."""


class Answer(BaseModel):
    text: str
    r"""An answer to a question."""

    evidence: Optional[List[str]] = None
    r"""The evidence used to derive the answer."""
