"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .basegetauthenticator import BaseGetAuthenticator, BaseGetAuthenticatorTypedDict
from .pagination import Pagination, PaginationTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AuthenticatorListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    authenticators: List[BaseGetAuthenticatorTypedDict]


class AuthenticatorList(BaseModel):
    pagination: Pagination

    authenticators: List[BaseGetAuthenticator]
