"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createauthenticatorconnection import (
    CreateAuthenticatorConnection,
    CreateAuthenticatorConnectionTypedDict,
)
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CreateAuthenticatorConnectionRequestTypedDict(TypedDict):
    authenticator_id: str
    create_authenticator_connection: CreateAuthenticatorConnectionTypedDict


class CreateAuthenticatorConnectionRequest(BaseModel):
    authenticator_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    create_authenticator_connection: Annotated[
        CreateAuthenticatorConnection,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
