"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from ragie.types import BaseModel
from typing_extensions import TypedDict


class Type(str, Enum):
    FILE = "file"
    FOLDER = "folder"


class SharepointFileDataTypedDict(TypedDict):
    id: str
    name: str
    type: Type


class SharepointFileData(BaseModel):
    id: str

    name: str

    type: Type
