"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .zendeskcredentials import ZendeskCredentials, ZendeskCredentialsTypedDict
from .zendeskdata import ZendeskData, ZendeskDataTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class PublicZendeskConnectionTypedDict(TypedDict):
    data: ZendeskDataTypedDict
    credentials: ZendeskCredentialsTypedDict
    provider: Literal["zendesk"]


class PublicZendeskConnection(BaseModel):
    data: ZendeskData

    credentials: ZendeskCredentials

    PROVIDER: Annotated[
        Annotated[Literal["zendesk"], AfterValidator(validate_const("zendesk"))],
        pydantic.Field(alias="provider"),
    ] = "zendesk"
