"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connectorsource import ConnectorSource
from ragie.types import BaseModel
from typing_extensions import TypedDict


class ConnectorSourceTypeInfoTypedDict(TypedDict):
    source_type: ConnectorSource
    display_name: str
    icon_url: str
    docs_url: str


class ConnectorSourceTypeInfo(BaseModel):
    source_type: ConnectorSource

    display_name: str

    icon_url: str

    docs_url: str
