"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class BackblazeCredentialsTypedDict(TypedDict):
    key_id: str
    application_key: str
    region: str
    endpoint: str


class BackblazeCredentials(BaseModel):
    key_id: str

    application_key: str

    region: str

    endpoint: str
