"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class SharepointSiteDataTypedDict(TypedDict):
    id: str
    name: str


class SharepointSiteData(BaseModel):
    id: str

    name: str
