"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class FreshdeskCredentialsTypedDict(TypedDict):
    domain: str
    api_key: str


class FreshdeskCredentials(BaseModel):
    domain: str

    api_key: str
