"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sharepointfiledata import SharepointFileData, SharepointFileDataTypedDict
from .sharepointsitedata import SharepointSiteData, SharepointSiteDataTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SharepointDataTypedDict(TypedDict):
    site: SharepointSiteDataTypedDict
    files: List[SharepointFileDataTypedDict]


class SharepointData(BaseModel):
    site: SharepointSiteData

    files: List[SharepointFileData]
