"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class ToolTypedDict(TypedDict):
    partitions: List[str]
    type: Literal["retrieve"]


class Tool(BaseModel):
    partitions: List[str]

    TYPE: Annotated[
        Annotated[Literal["retrieve"], AfterValidator(validate_const("retrieve"))],
        pydantic.Field(alias="type"),
    ] = "retrieve"
