"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class ConfluenceDataTypedDict(TypedDict):
    resource_id: str
    space_id: int
    space_key: str
    space_name: str


class ConfluenceData(BaseModel):
    resource_id: str

    space_id: int

    space_key: str

    space_name: str
