"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class DocumentSummaryTypedDict(TypedDict):
    document_id: str
    summary: str


class DocumentSummary(BaseModel):
    document_id: str

    summary: str
