"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class InputTokenDetailsTypedDict(TypedDict):
    cached_tokens: NotRequired[int]


class InputTokenDetails(BaseModel):
    cached_tokens: Optional[int] = 0
