"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connection import Connection, ConnectionTypedDict
from .pagination import Pagination, PaginationTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ConnectionListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    connections: List[ConnectionTypedDict]


class ConnectionList(BaseModel):
    pagination: Pagination

    connections: List[Connection]
