"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class ZendeskCredentialsTypedDict(TypedDict):
    domain: str
    email: str
    api_token: str


class ZendeskCredentials(BaseModel):
    domain: str

    email: str

    api_token: str
