"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class FolderDataTypedDict(TypedDict):
    folder_id: str
    folder_name: str


class FolderData(BaseModel):
    folder_id: str

    folder_name: str
