"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bucketdata import BucketData, BucketDataTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Any, Dict, Literal
from typing_extensions import Annotated, TypedDict


class PublicGCSConnectionTypedDict(TypedDict):
    data: BucketDataTypedDict
    credentials: Dict[str, Any]
    provider: Literal["gcs"]


class PublicGCSConnection(BaseModel):
    data: BucketData

    credentials: Dict[str, Any]

    PROVIDER: Annotated[
        Annotated[Literal["gcs"], AfterValidator(validate_const("gcs"))],
        pydantic.Field(alias="provider"),
    ] = "gcs"
