"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Any, Dict, Union
from typing_extensions import TypeAliasType, TypedDict


UpdateDocumentRawParamsDataTypedDict = TypeAliasType(
    "UpdateDocumentRawParamsDataTypedDict", Union[str, Dict[str, Any]]
)
r"""Document data in a text or JSON format."""


UpdateDocumentRawParamsData = TypeAliasType(
    "UpdateDocumentRawParamsData", Union[str, Dict[str, Any]]
)
r"""Document data in a text or JSON format."""


class UpdateDocumentRawParamsTypedDict(TypedDict):
    data: UpdateDocumentRawParamsDataTypedDict
    r"""Document data in a text or JSON format."""


class UpdateDocumentRawParams(BaseModel):
    data: UpdateDocumentRawParamsData
    r"""Document data in a text or JSON format."""
