"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .wordtimestamp import WordTimestamp, WordTimestampTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class VideoModalityDataTypedDict(TypedDict):
    type: Literal["video"]
    word_timestamps: NotRequired[List[WordTimestampTypedDict]]


class VideoModalityData(BaseModel):
    TYPE: Annotated[
        Annotated[Optional[Literal["video"]], AfterValidator(validate_const("video"))],
        pydantic.Field(alias="type"),
    ] = "video"

    word_timestamps: Optional[List[WordTimestamp]] = None
